@@ -8,6 +8,7 @@ from itertools import chain
 import portage
 from portage import normalize_path
 from portage import os
+from portage._sets.base import InternalPackageSet
 from portage.output import green
 from portage.util.futures.extendedfutures import ExtendedFuture
 from repoman.metadata import get_metadata_xsd
@@ -93,6 +94,9 @@ class Scanner(object):
 			'profile_list': profile_list,
 			'pmaskdict': global_pmaskdict,
 			'lic_deprecated': liclist_deprecated,
+			'package.deprecated': InternalPackageSet(initial_atoms=portage.util.stack_lists(
+				[portage.util.grabfile_package(os.path.join(path, 'profiles', 'package.deprecated'), recursive=True)
+				for path in self.portdb.porttrees], incremental=True))
 		}
 
 		self.repo_settings.repoman_settings['PORTAGE_ARCHLIST'] = ' '.join(sorted(kwlist))
